@@ -79,3 +79,34 @@ class Wsdl:
         view = ViewInfo(dv,viewparams=params)
         self.set_cache(sid, 'desktop', "vars",dv,smart=False)
         return view
+
+    @rpc(Integer, DesktopInfo, _returns = Array(ReturnedMessage))
+    @core_method(category=__('Desktop'),title=__('Logout user'),
+        image='system-log-out',
+        gui=True,command='cl-desktop-logout',
+        rights=['userconfigure'])
+    def desktop_logout(self, sid, info):
+        return self.callMethod(sid,info,method_name="desktop_logout",
+                               logicClass=Desktop,
+                               method="userLogout")
+
+    def desktop_logout_vars(self,dv=None):
+        if not dv:
+            dv = DataVarsDesktop()
+            dv.importDesktop()
+            dv.flIniFile()
+        dv.addGroup(None,
+            normal=('ur_login',),
+            next_label=_("Logout"),)
+        return dv
+
+    @rpc(Integer, ViewParams,_returns = ViewInfo)
+    def desktop_logout_view (self, sid, params):
+        dv = self.get_cache(sid,"desktop_logout","vars")
+        if not dv:
+            dv = self.desktop_logout_vars()
+        else:
+            dv.processRefresh()
+        view = ViewInfo(dv,viewparams=params)
+        self.set_cache(sid, 'desktop_logout', "vars",dv,smart=False)
+        return view
