@@ -1,8 +1,11 @@
 import os
 import sys
+import re
 from os import path
-from calculate.lib.datavars import Variable,VariableError,ReadonlyVariable
-from calculate.lib.utils.files import readLinesFile
+from calculate.lib.datavars import Variable,VariableError,ReadonlyVariable, \
+                    ReadonlyTableVariable,FieldValue
+from calculate.lib.utils.files import readLinesFile,process
+from itertools import *
 
 from calculate.lib.cl_lang import setLocalTranslate
 setLocalTranslate('cl_desktop3',sys.modules[__name__])
@@ -151,3 +154,62 @@ class VariableClDesktopXfceMixer(ReadonlyVariable):
         return "\n".join(
                map(lambda x:'      <value type="string" value="%s" />'%x,
                self.Get('cl_desktop_gst_data').get('channels',[])))
+
+class VariableClDesktopOnlineData(ReadonlyTableVariable):
+    """
+    Information about online users
+    """
+    source = ['cl_desktop_online_user',
+              'cl_desktop_online_display']
+
+    reDisplay = re.compile(r"^\(?:(\d+\.?\d*)")
+
+    def _getDisplay(self,*args):
+        """
+        Get DISPLAY from args
+        """
+        for arg in map(self.reDisplay.search,args):
+            if arg:
+                return arg.group(1)
+        return ""
+
+    def get(self,hr=False):
+        xSession = 0
+        foundTwoSession = False
+        resWho = process("who")
+        xData = [[]]
+        if resWho.success():
+            listProcessing = lambda x: (x[0], x[1], x[-1]) \
+                             if len(x)>=5 else []
+            xData = map(lambda x:x[1].next(),
+                    groupby(
+                    sorted(
+                    filter(lambda x: x[0]!="root",
+                    map(lambda x: (x[0],self._getDisplay(x[1],x[2])),
+                    filter(lambda x: x and\
+                              (x[2].startswith("(:") or \
+                               x[1].startswith(":")),
+                    map(lambda x: listProcessing(\
+                    filter(lambda y: y, x.split())),
+                    resWho)))),
+                    key=lambda x:x[0]),
+                    lambda x:x[0]))
+        return xData
+
+    setValue = Variable.setValue
+
+class VariableClDesktopOnlineUser(FieldValue,ReadonlyVariable):
+    """
+    User name
+    """
+    type = "list"
+    source_variable = "cl_desktop_online_data"
+    column = 0
+
+class VariableClDesktopOnlineDisplay(FieldValue,ReadonlyVariable):
+    """
+    Display for user
+    """
+    type = "list"
+    source_variable = "cl_desktop_online_data"
+    column = 1
